Vertical Example
===============================================================================

:download:`vertical.enaml <../../../examples/layout/basic/vertical.enaml>`

.. literalinclude:: ../../../examples/layout/basic/vertical.enaml
    :language: python

::

 $ enaml-run vertical.enaml

.. image:: images/vertical.png
